@@ -9,6 +9,22 @@ class SMCException(Exception):
     """ Base class for exceptions """
 
 
+class SessionNotFound(SMCException):
+    """
+    Retrieving a session by name did not succeed because the session did
+    not already exist
+    """
+
+
+class SessionManagerNotFound(Exception):
+    def __init__(self, message=''):
+        msg = 'A session manager was not found for this session. This generally means '\
+        'the session was not obtained through the standard session factory or the session '\
+        'manager may have been replaced. '
+        _msg = message or msg
+        super(SessionManagerNotFound, self).__init__(_msg)
+
+
 class ConfigLoadError(SMCException):
     """
     Thrown when there was a problem reading credential information from
@@ -60,7 +76,6 @@ class SMCOperationFailure(SMCException):
             except ValueError:
                 message = 'No valid message returned from SMC server'
             else:
-                #status = data.get('status', None)
                 message = data.get('message', None)
                 details = data.get('details', None)
         else:  # it's not json
@@ -198,6 +213,12 @@ class ModificationAborted(SMCException):
     """
 
 
+class MissingDependency(SMCException):
+    """
+    A dependency is missing for the given operation.
+    """
+    
+
 class ActionCommandFailed(SMCException):
     """
     Action type commands use this exception
