@@ -20,9 +20,9 @@ import re
 import copy
 from itertools import islice
 import smc.base.model
-from smc.api.entry_point import Resource
 from smc.base.decorators import cached_property, classproperty
 from smc.api.exceptions import FetchElementFailed, InvalidSearchFilter
+from smc.api.common import entry_point
     
 
 class SubElementCollection(object):
@@ -72,7 +72,24 @@ class SubElementCollection(object):
     def __iter__(self):
         self._fetch_all()
         return iter(self._result_cache)
-
+    
+    def __getitem__(self, key):
+        return self._result_cache[key]
+    
+    def _load_from_engine(self, engine, reference):
+        resources = []
+        for r in engine.data.get(reference, []):
+            for _, data in r.items():    
+                cache = smc.base.model.ElementCache(data)
+                res = self.cls(
+                    name=cache.get('name'),
+                    href=cache.get_link('self'),
+                    type=cache.type)
+                res.data = cache
+                res._engine = engine
+                resources.append(res)
+        self._result_cache = resources
+    
     def _fetch_all(self):
         if self._result_cache is None:
             results = smc.base.model.prepared_request(
@@ -740,7 +757,7 @@ class Search(ElementCollection):
 
     def __init__(self, **params):
         super(Search, self).__init__(**params)
-        self._resource = Resource()
+        self._resource = entry_point()
     
     @classproperty
     def objects(self):
@@ -811,6 +828,6 @@ class Search(ElementCollection):
         # Return all elements from the root of the API nested under elements URI
         #element_uri = str(
         types = [element.rel
-                 for element in Resource.entry_point]
+                 for element in entry_point()]
         types.extend(list(CONTEXTS))
         return types
