@@ -1,10 +1,9 @@
 from collections import namedtuple
 from smc.elements.helpers import domain_helper, location_helper
-from smc.base.model import Element, \
-    SubElement, lookup_class, SubElementCreator
+from smc.base.model import Element, SubElement, lookup_class, ElementCreator
 from smc.api.exceptions import UnsupportedEngineFeature,\
     UnsupportedInterfaceType, EngineCommandFailed, SMCConnectionError
-from smc.core.node import Node, NodeCollection
+from smc.core.node import Node
 from smc.core.resource import Snapshot, PendingChanges
 from smc.core.interfaces import InterfaceOptions, PhysicalInterface
 from smc.core.collection import InterfaceCollection, LoopbackCollection,\
@@ -453,9 +452,15 @@ class Engine(Element):
             
         
         :return: nodes for this engine
-        :rtype: NodeCollection
+        :rtype: SubElementCollection(Node)
         """
-        return NodeCollection(self)
+        resource = sub_collection(
+            self.get_relation( 
+                'nodes'), 
+            Node) 
+        resource._load_from_engine(self, 'nodes') 
+        return resource
+        
 
     @property
     def permissions(self):
@@ -522,7 +527,7 @@ class Engine(Element):
         """
         alias_list = list(Alias.objects.all())
         for alias in self.make_request(resource='alias_resolving'):
-            yield Alias.from_engine(alias, alias_list)
+            yield Alias._from_engine(alias, alias_list)
 
     def blacklist(self, src, dst, duration=3600, **kw):
         """
@@ -787,11 +792,13 @@ class Engine(Element):
         :raises UnsupportedEngineFeature: master engine only
         :rtype: CreateCollection(VirtualResource)
         """
-        return create_collection(
+        resource = create_collection(
             self.get_relation(
                 'virtual_resources',
                 UnsupportedEngineFeature),
             VirtualResource)
+        resource._load_from_engine(self, 'virtualResources')
+        return resource
 
     @property
     def contact_addresses(self):
@@ -811,15 +818,18 @@ class Engine(Element):
             >>> for ca in engine.contact_addresses:
             ...   ca
             ... 
-            ContactAddressInterface(interface_id=11, interface_ip=10.10.10.20)
-            ContactAddressInterface(interface_id=120, interface_ip=120.120.120.100)
-            ContactAddressInterface(interface_id=0, interface_ip=1.1.1.1)
-            ContactAddressInterface(interface_id=12, interface_ip=3.3.3.3)
-            ContactAddressInterface(interface_id=12, interface_ip=17.17.17.17)
+            ContactAddressNode(interface_id=11, interface_ip=10.10.10.20)
+            ContactAddressNode(interface_id=120, interface_ip=120.120.120.100)
+            ContactAddressNode(interface_id=0, interface_ip=1.1.1.1)
+            ContactAddressNode(interface_id=12, interface_ip=3.3.3.3)
+            ContactAddressNode(interface_id=12, interface_ip=17.17.17.17)
         
         .. seealso:: :py:mod:`smc.core.contact_address`
-
-        :rtype: ContactAddressCollection(ContactInterfaceAddress)
+        
+        This is set to a private method because the logic doesn't make sense with
+        respects to how this is configured under the SMC.
+        
+        :rtype: ContactAddressCollection(ContactAddressNode)
         """
         return ContactAddressCollection(
             self.get_relation('contact_addresses'))        
@@ -1498,11 +1508,8 @@ class VirtualResource(SubElement):
                 'vfw_id': vfw_id,
                 'comment': comment,
                 'allocated_domain_ref': allocated_domain}
-
-        return SubElementCreator(
-            self.__class__,
-            href=self.href,
-            json=json)
+        
+        return ElementCreator(self.__class__, json=json, href=self.href)
         
     @property
     def allocated_domain_ref(self):
@@ -1544,3 +1551,4 @@ class VirtualResource(SubElement):
         :rtype: int
         """
         return self.data.get('vfw_id')
+    
