@@ -15,33 +15,10 @@ For example, to load an engine and run node level commands::
 """
 import collections
 from smc.base.util import save_to_file, b64encode
-from smc.base.model import SubElement, ElementCache
+from smc.base.model import SubElement
 from smc.core.sub_interfaces import LoopbackInterface
 from smc.api.exceptions import LicenseError, NodeCommandFailed
-from smc.base.structs import SerializedIterable, BaseIterable
-
-
-class NodeCollection(BaseIterable):
-    """
-    Node Collection provides a simplified interface to retrieving
-    nodes from an engine reference::
-    
-        engine.nodes.get(0)
-        engine.nodes.all()
-    
-    :rtype: Node
-    """
-    def __init__(self, engine):
-        nodes = Node._load(engine)
-        super(NodeCollection, self).__init__(nodes)
-    
-    def get(self, nodeid):
-        """
-        Get a node by Node ID
-        
-        :rtype: Node
-        """
-        return super(NodeCollection, self).get(nodeid=nodeid)
+from smc.base.structs import SerializedIterable
         
 
 class Node(SubElement):
@@ -96,20 +73,6 @@ class Node(SubElement):
         # Delete cache from engine reference
         super(Node, self).update(*args, **kw)
         self._engine._del_cache()
-    
-    @classmethod
-    def _load(cls, engine):
-        nodes = []
-        for node in engine.data.get('nodes', []):
-            for typeof, data in node.items():
-                cache = ElementCache(data)
-                node = Node(name=cache.get('name'),
-                            href=cache.get_link('self'),
-                            type=typeof)
-                node.data = cache
-                node._engine = engine
-                nodes.append(node)
-        return nodes
 
     @classmethod
     def _create(cls, name, node_type, nodeid=1,
@@ -246,7 +209,17 @@ class Node(SubElement):
                         'Error occurred when attempting to save initial '
                         'contact to file: {}'.format(e))
         return result.content
-
+    
+    def dynamic_element_update(self, name_cache_object):
+        """
+        """
+        return self.make_request(
+            NodeCommandFailed,
+            method='create',
+            resource='dynamic_element_update',
+            headers = {'content-type': 'multipart/form-data'},
+            files = {'update_file': name_cache_object.serialize()})
+        
     @property
     def interface_status(self):
         """
@@ -338,7 +311,7 @@ class Node(SubElement):
         result = self.make_request(
             NodeCommandFailed,
             resource='status')
-
+        
         return ApplianceStatus(**result)
 
     def go_online(self, comment=None):
@@ -597,8 +570,9 @@ class Node(SubElement):
 
 
 ApplianceStatus = collections.namedtuple('ApplianceStatus', 
-    'configuration_status dyn_up installed_policy name platform state status version')      
-
+    'configuration_status dyn_up installed_policy name platform state status version '
+    'engine_node_status monitoring_state monitoring_status')      
+ 
 """
 Appliance status attributes define specifics about the hardware platform
 itself, including version, dynamic package, current configuration status
@@ -633,6 +607,10 @@ Retrieve appliance status for engine nodes::
     Valid values:
         INITIAL/READY/ERROR/SERVER_ERROR/NO_STATUS/TIMEOUT/
         DELETED/DUMMY
+        
+.. versionchanged:: 0.6.2
+    Attribute status changed to monitoring_status and state to monitoring_state
+    in SMC 6.5
 """
 ApplianceStatus.__new__.__defaults__ = (None,) * len(ApplianceStatus._fields)
 
