@@ -46,7 +46,8 @@ Only Layer3Firewall and Layer3VirtualEngine types can support running OSPF.
              :py:class:`smc.core.engines.Layer3VirtualEngine`
 
 """
-from smc.base.model import Element, ElementCreator, ElementCache, ElementRef
+from smc.base.model import Element, ElementCreator, ElementCache, ElementRef,\
+    ElementList
 from smc.base.util import element_resolver
 
 
@@ -94,8 +95,7 @@ class OSPF(object):
 
         :return: None
         """
-        self.data.update(
-            enabled=False)
+        self.data.update(enabled=False)
 
     def enable(self, ospf_profile=None, router_id=None):
         """
@@ -195,11 +195,17 @@ class OSPFArea(Element):
                      'substitute_type': 'aggregate'}])
     
     :ivar OSPFInterfaceSetting interface_settings_ref: reference to the OSPFInterfaceSetting
-        element
+    :ivar list(IPPrefixList,IPAccessList) inbound_filters: Inbound filters attached to this
+        OSPF Area.
+    :ivar list(IPPrefixList,IPAccessList) outbound_filters: Outbound filter attached to this
+        OSPF Area.
     """
     typeof = 'ospfv2_area'
     interface_settings_ref = ElementRef('interface_settings_ref')
-
+    inbound_filters = ElementList('inbound_filters_ref')
+    outbound_filters = ElementList('outbound_filters_ref')
+    
+    
     @classmethod
     def create(cls, name, interface_settings_ref=None, area_id=1,
                area_type='normal', outbound_filters=None,
@@ -251,36 +257,14 @@ class OSPFArea(Element):
         return ElementCreator(cls, json)
 
     @classmethod
-    def update_or_create(cls, filter_key=None, with_status=False, **kwargs):
+    def update_or_create(cls, with_status=False, **kwargs):
         if 'inbound_filters' in kwargs:
             kwargs.update(inbound_filters_ref=
                 element_resolver(kwargs.pop('inbound_filters')))
         if 'outbound_filters' in kwargs:
             kwargs.update(outbound_filters_ref=
                 element_resolver(kwargs.pop('outbound_filters')))
-        return super(OSPFArea, cls).update_or_create(filter_key, with_status, **kwargs)
-
-    @property
-    def inbound_filters(self):
-        """
-        Inbound filters attached to this OSPF Area. Filters can be type
-        IPPrefixList or IPAccessList
-        
-        :rtype: list
-        """
-        return [Element.from_href(filt)
-            for filt in self.data.get('inbound_filters_ref', [])]
-    
-    @property
-    def outbound_filters(self):
-        """
-        Outbound filters attached to this OSPF Area. Filters can be type
-        IPPrefixList or IPAccessList
-        
-        :rtype: list
-        """
-        return [Element.from_href(filt)
-            for filt in self.data.get('outbound_filters_ref', [])]
+        return super(OSPFArea, cls).update_or_create(with_status=with_status, **kwargs)
 
 
 class OSPFInterfaceSetting(Element):
@@ -492,13 +476,25 @@ class OSPFProfile(Element):
         json.update(domain_settings_ref=domain_settings_ref)
 
         return ElementCreator(cls, json)
-        
+    
     @classmethod
     def update_or_create(cls, filter_key=None, with_status=False, **kwargs):
         if 'redistribution_entry' in kwargs:
             kwargs.update(redistribution_entry=_format_redist_entry(
                 kwargs.pop('redistribution_entry', [])))
-        return super(OSPFProfile, cls).update_or_create(filter_key, with_status, **kwargs)
+        
+        element, updated, created = super(OSPFProfile, cls).update_or_create(
+            filter_key, defer_update=True, **kwargs)
+        if not created:
+            # Deferred update, update redistribution settings
+            if 'redistribution_entry' in kwargs:
+                element.data['redistribution_entry'] = kwargs.get('redistribution_entry')
+                element.update()
+                updated = True
+        
+        if with_status:
+            return element, updated, created
+        return element
 
 
 class OSPFDomainSetting(Element):
